Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(352)

Unified Diff: content/browser/web_contents/render_view_host_manager.h

Issue 10377158: Move keyboard related methods from RenderViewHostDelegate to a new RenderWidgetHostDelegate (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: remove crbug link Created 8 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/web_contents/render_view_host_manager.h
diff --git a/content/browser/web_contents/render_view_host_manager.h b/content/browser/web_contents/render_view_host_manager.h
index 2d9a384a97a944f609cda5aaf9bcf256432e6261..cb78442c1d723730344b2c771068adbb40a9f090 100644
--- a/content/browser/web_contents/render_view_host_manager.h
+++ b/content/browser/web_contents/render_view_host_manager.h
@@ -26,6 +26,7 @@ class NavigationEntry;
class NavigationEntryImpl;
class RenderViewHost;
class RenderViewHostImpl;
+class RenderWidgetHostDelegate;
class RenderWidgetHostView;
class TestWebContents;
}
@@ -100,13 +101,16 @@ class CONTENT_EXPORT RenderViewHostManager
virtual ~Delegate() {}
};
// Both delegate pointers must be non-NULL and are not owned by this class.
// They must outlive this class. The RenderViewHostDelegate is what will be
// installed into all RenderViewHosts that are created.
//
// You must call Init() before using this class.
- RenderViewHostManager(content::RenderViewHostDelegate* render_view_delegate,
- Delegate* delegate);
+ RenderViewHostManager(
+ content::RenderViewHostDelegate* render_view_delegate,
+ content::RenderWidgetHostDelegate* render_widget_delegate,
+ Delegate* delegate);
virtual ~RenderViewHostManager();
// For arguments, see WebContentsImpl constructor.
@@ -279,9 +283,10 @@ class CONTENT_EXPORT RenderViewHostManager
// for the view type (like view source versus not).
bool cross_navigation_pending_;
- // Implemented by the owner of this class, this delegate is installed into all
- // the RenderViewHosts that we create.
+ // Implemented by the owner of this class, these delegates are installed into
+ // all the RenderViewHosts that we create.
content::RenderViewHostDelegate* render_view_delegate_;
+ content::RenderWidgetHostDelegate* render_widget_delegate_;
// Our RenderView host and its associated Web UI (if any, will be NULL for
// non-DOM-UI pages). This object is responsible for all communication with
« no previous file with comments | « content/browser/web_contents/interstitial_page_impl.cc ('k') | content/browser/web_contents/render_view_host_manager.cc » ('j') | no next file with comments »
@@ -100,13 +101,16 @@ class CONTENT_EXPORT RenderViewHostManager
virtual ~Delegate() {}
};
- // Both delegate pointers must be non-NULL and are not owned by this class.
- // They must outlive this class. The RenderViewHostDelegate is what will be
- // installed into all RenderViewHosts that are created.
+ // All three delegate pointers must be non-NULL and are not owned by this
+ // class. They must outlive this class. The RenderViewHostDelegate and
+ // RenderWidgetHostDelegate are what will be installed into all
+ // RenderViewHosts that are created.
//
// You must call Init() before using this class.

Powered by Google App Engine
This is Rietveld 408576698